/*
    CREATION OF STARTING POPULATIONS
	MARTIN SPIELAUER, 2016
	CENSUS 2013 12% SAMPLE
*/

/* ************************ */
/* DATA RESIDENT POPULATION */
/* ************************ */

clear all
#delimit; 
use "Microdata\m_census_residents.dta";

/* ************************ */
/* DISTRIBUTIONAL TABLE 	*/
/* ************************ */

gen M_NAGE = int(M_AGE);


/* ************************ */
/* RANDOM ORDER CSV FILE    */
/* ************************ */

gen M_RAND = runiform();
sort M_RAND;

/* Add a variable for most recent birth - valuses are set missing */
gen M_AGEBIR = .;

/*
classification PERSON_MICRODATA_COLUMNS         //EN fields in the microdata input file 
{
    PMC_WEIGHT,                                 //EN Weight
    PMC_BIRTH,                                  //EN Time of birth
    PMC_SEX,                                    //EN Sex
    PMC_PROVINCE,                               //EN Province
    PMC_EDUC,                                   //EN Education
    PMC_POB,                                    //EN Province of birth
    PMC_UNION,                                  //EN Union formation time
    PMC_PARITY,                                 //EN Number of births
    PMC_LASTBIR                                 //EN Time of last birth
};
*/

gen PMC_WEIGHT = M_WEIGHT;
gen PMC_BIRTH = 2013 - M_AGE;
gen PMC_SEX = M_MALE;
gen PMC_PROVINCE = M_POR;
gen PMC_EDUC = M_EDUC;
gen PMC_POB = M_POB;
gen PMC_UNION = 9999; replace PMC_UNION = PMC_BIRTH + M_AGEMAR if M_AGEMAR !=.;
gen PMC_PARITY = M_PARITY;
gen PMC_LASTBIR = 9999; replace PMC_LASTBIR = PMC_BIRTH + M_AGEBIR if M_AGEBIR !=.;

replace PMC_LASTBIR = 2013-runiform() if PMC_PARITY >= 1 & M_AGE < 15;

replace PMC_LASTBIR = 2013-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.5017) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.2779) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.2100) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.1382) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.0816) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.0274) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.0000) );

replace PMC_LASTBIR = 2013-1-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.5933) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.3628) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.2778) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.1450) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.1111) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.0422) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.0000) );

replace PMC_LASTBIR = 2013-2-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.5574) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.4554) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.2363) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.1667) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.0750) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.0735) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.0000) );

replace PMC_LASTBIR = 2013-3-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.5185) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.3910) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.2877) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.0851) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.0546) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.0635) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.0000) );

replace PMC_LASTBIR = 2013-4-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.385) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.418) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.212) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.140) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.143) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.017) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.000) );

replace PMC_LASTBIR = 2013-5-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.750) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.436) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.282) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.081) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.067) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.052) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.022) );

replace PMC_LASTBIR = 2013-6-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.500) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.500) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.232) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.147) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.179) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.018) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.023) );
  
replace PMC_LASTBIR = 2013-7-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 1.001) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.364) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.326) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.121) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.217) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.074) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.000) );
  
replace PMC_LASTBIR = 2013-8-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.000) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.429) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.414) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.118) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.139) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.040) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.023) );

replace PMC_LASTBIR = 2013-9-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.000) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.250) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.294) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.267) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.097) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.000) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.023) );

replace PMC_LASTBIR = 2013-10-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.000) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.667) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.250) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.273) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.214) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.083) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.098) );

replace PMC_LASTBIR = 2013-11-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1 & (
  ( M_AGE >= 15 & M_AGE < 20 & runiform() < 0.000) | 
  ( M_AGE >= 20 & M_AGE < 25 & runiform() < 0.000) | 
  ( M_AGE >= 25 & M_AGE < 30 & runiform() < 0.556) | 
  ( M_AGE >= 30 & M_AGE < 35 & runiform() < 0.125) | 
  ( M_AGE >= 35 & M_AGE < 40 & runiform() < 0.091) | 
  ( M_AGE >= 40 & M_AGE < 45 & runiform() < 0.068) | 
  ( M_AGE >= 45 & M_AGE < 50 & runiform() < 0.054) );
  
replace PMC_LASTBIR = 2013-12-runiform() if PMC_LASTBIR == 9999 & PMC_PARITY >= 1;

keep PMC_*;
export delimited using "Microdata\m1_census_starting_population", novarnames nolabel replace;


