/*
    MIGRATION
	MARTIN SPIELAUER, 2016
*/

/* ************************* */
/* DATA: RESIDENT POPULATION */
/* ************************* */

clear all
#delimit; 
use "Microdata\m_census_residents.dta";

/* ************************* */
/* VARIABLES                 */
/* ************************* */

/* Age one year ago, drop if < 0 */
gen m_ageago = int(M_AGE)-1; drop if m_ageago < 0;

/* Age groups 5 years ago, up to 60+ */
gen m_agegr5 = 5 * int(m_ageago / 5); replace m_agegr5 = 60 if m_agegr5 > 60;

/* Person is internal migrant (moved within the country)*/
gen is_migrant = 0; replace is_migrant = 1 if M_PPROV != M_POR & M_PPROV != 13;

/* Append (very) low weighted transition records of all possible transitions to avoid empty cells */
append using "D:\Dropbox\WorldBank2016_MS\Census\m_empty_migrants.dta";

/* Person is potential migrant (not a recent immigrant) -- drop others */
drop if M_PPROV == 13; 


/* ************************* */
/* MODELS                    */
/* ************************* */

/* Leaving */

xi: logit is_migrant i.m_agegr5 i.M_PPROV [iweight=M_WEIGHT] if M_MALE == 0;
xi: logit is_migrant i.m_agegr5 i.M_PPROV [iweight=M_WEIGHT] if M_MALE == 1;

/* Destinations by origin */

by M_PPROV M_MALE, sort : tabulate m_agegr5 M_POR [iweight = M_WEIGHT] if is_migrant, nolab row nofr;

/* All: for descriptive table */

tabulate m_agegr5 M_POR [iweight = M_WEIGHT] if is_migrant, nolab row nofr;

