/*
    IMMIGRATION
	MARTIN SPIELAUER, 2016
*/

/* ******************************** */
/* DATA: IMMIGRANT POPULATION       */
/* ******************************** */

clear all
#delimit; 
use "Microdata\m_census_immigrants.dta";

/* ******************************** */
/* VARIABLES                        */
/* ******************************** */

/* Age at immigration: 50% chance of having been a year younger 
   The high number of 0 year old is unrealistic, 50% are given a random age < 10
*/
gen m_age = int(M_AGE); 
replace m_age = m_age-1 if runiform()<0.5; replace m_age = 0 if m_age < 0;
replace m_age = m_age + int( 10 * runiform() ) if m_age== 0 & runiform()<0.5;
tab m_age;

/* 5 year age groups, age at immigration, up to 60+ */	
gen m_agegr5 = 5 * int(m_age / 5);
	replace m_agegr5 = 60 if m_agegr5 > 60;
	label define l_agegr5 
		0 "0-4" 
		5 "5-9" 
		10 "10-14" 
		15 "15-19" 
		20 "20-24" 
		25 "25-29" 
		30 "30-34" 
		35 "35-34" 
		40 "40-44" 
		45 "45-49" 
		50 "50-54" 
		55 "55-59" 
		60 "60+" ;
	label values m_agegr5 l_agegr5;
	
/* Append (very) low weighted records of all possible destinations to avoid empty cells */
append using "Microdata\m_empty_immigrants.dta";	

/* ******************************** */
/* VARIABLES                        */
/* ******************************** */

/* TAB 01: Number of immigrants by sex */
tabulate M_MALE [iweight = M_WEIGHT]; 

/* TAB 02: Destination of immigrants */
by M_MALE , sort : tabulate m_agegr5 M_POR  [iweight = M_WEIGHT], row nofr; 
	
/* TAB 03: Age distribution of immigrants by sex */
tabulate m_age M_MALE [iweight = M_WEIGHT], col nofr; 


