* FIRST UNION FORMATION MAURITANIA - MARTIN SPIELAUER, 2016

* -------------------------------
* Wrapper function stpiece
* -------------------------------

* the following adds the wrapper function stpiece which can be used to make code more efficient;
* without this function, time splits of the baseline duration have to be done manually;
* the fuction can be added to Stata, download at: http://fmwww.bc.edu/repec/bocode/s/stpiece.ado;
* it was developed by Jesper B. Sorensen Nov. 20 1999;

* THIS FILE STILL HAS TO BE ADAPTED TO WORK WITH THE FINAL CENSUS ANALYSIS FILE;

clear all

program define stpiece
    version 6.0
    syntax [varlist(default=none numeric)] [if] [in] , [tp(numlist >=0) tv(varlist) PREsplit(integer -1) noPREserve *]
    if "`preserv'"=="" {
        preserve
    }
    if "`presplit'" == "-1" {
        if "`tp'"=="" {
            di in red "You must either declare data to be presplit or use tp()"
            exit 198
        }
        di in gr "Invoking stsplit..."
        qui stsplit tp, at(`tp') 
        di in gr "Creating time pieces..."
        qui tab tp, gen(tp)
        local i = _result(2)
        drop tp
    }
    else {
        local i = "`presplit'"
    }
    if "`tv'" ~= "" {
        di in gr "Creating interaction effects..."
        tokenize `tv'
        while "`1'" ~= "" {
            local stub = substr("`1'",1,4)
            local j=0
            while "`j'" < "`i'" {
                local j = `j'+1
                local x = "tp`stub'`j'"
                qui gen  `x'=`1'*tp`j'
            }
         mac shift
        }
    }

    streg tp* `varlist' `if' `in' , nocons d(e) `options'

end

* ----------------------------------------------------
* ANALYSIS VARIABLES;
* ----------------------------------------------------

use "D:\Dropbox\WorldBank2016_MS\Census\MRT_2013_Census_10percent_Stata-old.dta"

// Sample: Females age 16+, known education (few exclusions)

drop if age < 16
*drop if age > 49
drop if Q04 == 1

gen m_weight = round(pondfact*10)

// Education

generate m_educ = -1									//unknown;
	replace m_educ = 0 if niv_inst==1 					//never entered any education;
	replace m_educ = 1 if niv_inst==2 					//Coranique;
	replace m_educ = 2 if niv_inst==3 &  Q20==0		//Started Primary;
	replace m_educ = 3 if niv_inst==3 &  Q20==10		//Finished Primary, no other studies;
	replace m_educ = 4 if niv_inst>3  &  Q20==10		//Startded secondary;
	replace m_educ = 5 if Q20 < 26 	  &  Q20>10		//Secondary diploma brevet+;

	drop if m_educ==-1	
	
	replace m_educ = 0 if m_educ == 1					//Coranique moved to no education;
	replace m_educ = 1 if m_educ == 2					//Enter primary;
	replace m_educ = 2 if m_educ > 2					//Graduated from primary;
	
	char m_educ[omit]1

// Province of birth	
	
generate m_pob = Q13
	replace m_pob = 14 if m_pob>13
	label value m_pob ID1	
	char m_pob[omit]13
	
// year of birth
	
generate m_yob = Q05A
	replace m_yob = 2012-age if m_yob>2013
*	drop if m_yob < 1963
	
generate m_agemar = Q28
	drop if m_agemar==98
	replace m_agemar = m_agemar + runiform()
	drop if m_agemar < 99 & m_agemar + m_yob > 2012.99
keep m_*

generate RecNo = _n

* Person was ever in a union - this is the event studied;

generate EverInUnion = 0
replace  EverInUnion = 1 if m_agemar != .

* Observation time;

generate DUR = 2013 - m_yob - 10
replace  DUR = m_agemar - 10 if EverInUnion==1

* Censor at age 50 

drop if DUR < 0 
replace EverInUnion = 0 if DUR > 40
replace DUR = 40 if DUR > 39



* -------------------------------------------------------------;
* EPISODE SPLITTING;
* -------------------------------------------------------------;

* stset tells Stata what is the waiting time and what is the event and the persons id;
* the id is needed, as the records will be split up into episodes;
 
stset DUR, failure(EverInUnion) id(RecNo)

* splitting file in period episodes;

stsplit m_period, after at ( 5 15 25 ) ( time =  1980 - m_yob - 10)

	replace m_period = 4 if m_period==25
	replace m_period = 3 if m_period==15
	replace m_period = 2 if m_period==5
	replace m_period = 1 if m_period==0
drop if m_period==1	

stsplit m_agegr, after at (10, 20 ) (time=0)

	replace m_agegr = 1 + m_agegr/10

generate m_ageXperiod = m_agegr * 10 + m_period
replace m_ageXperiod = 0 if m_period==4

* Estimation;

xi: stpiece i.m_ageXperiod if m_educ==0, tp( 5, 10, 15, 20, 25, 30, 35 )
xi: stpiece i.m_ageXperiod if m_educ==1, tp( 5, 10, 15, 20, 25, 30, 35 )
xi: stpiece i.m_ageXperiod if m_educ==2, tp( 5, 10, 15, 20, 25, 30, 35 )


