/*
    FIRST UNION FORMATION MAURITANIA
	MARTIN SPIELAUER, 2016
*/


/* 
-------------------------------
Wrapper function stpiece
-------------------------------

the following adds the wrapper function stpiece which can be used to make code more efficient
without this function, time splits of the baseline duration have to be done manually
the fuction can be added to Stata, download at: http://fmwww.bc.edu/repec/bocode/s/stpiece.ado
it was developed by Jesper B. Sorensen Nov. 20 1999
*/

clear all

program define stpiece
    version 6.0
    syntax [varlist(default=none numeric)] [if] [in] , [tp(numlist >=0) tv(varlist) PREsplit(integer -1) noPREserve *]
    if "`preserv'"=="" {
        preserve
    }
    if "`presplit'" == "-1" {
        if "`tp'"=="" {
            di in red "You must either declare data to be presplit or use tp()"
            exit 198
        }
        di in gr "Invoking stsplit..."
        qui stsplit tp, at(`tp') 
        di in gr "Creating time pieces..."
        qui tab tp, gen(tp)
        local i = _result(2)
        drop tp
    }
    else {
        local i = "`presplit'"
    }
    if "`tv'" ~= "" {
        di in gr "Creating interaction effects..."
        tokenize `tv'
        while "`1'" ~= "" {
            local stub = substr("`1'",1,4)
            local j=0
            while "`j'" < "`i'" {
                local j = `j'+1
                local x = "tp`stub'`j'"
                qui gen  `x'=`1'*tp`j'
            }
         mac shift
        }
    }

    streg tp* `varlist' `if' `in' , nocons d(e) `options'

end

/* ****************************************** */
/* DATA: FEMALE RESIDENT POPULATION AGE 16+   */
/* ****************************************** */

#delimit; 
use "D:\Dropbox\WorldBank2016_MS\Census\m_census_residents.dta";

drop if M_MALE == 1;
drop if M_AGE < 16;

/* ****************************************** */
/* VARIABLES							      */
/* ****************************************** */
	
generate m_yob = 2013 - M_AGE;

generate m_cohort = 6;
	replace m_cohort = 5 if m_yob >= 1955;
	replace m_cohort = 4 if m_yob >= 1965;
	replace m_cohort = 3 if m_yob >= 1975;
	replace m_cohort = 2 if m_yob >= 1985;
	replace m_cohort = 1 if m_yob >= 1995;

generate RecNo = _n;

/* Person was ever in a union - this is the event studied */

generate EverInUnion = 0;
replace  EverInUnion = 1 if M_AGEMAR != .;

/* Observation time. Marriages below age 10 moved to a random moment at age 10 */

generate DUR = M_AGE - 10;
replace  DUR = M_AGEMAR - 10 if EverInUnion==1;
replace  DUR = runiform() if DUR < 0;

/* Censor at age 50 */

replace EverInUnion = 0 if DUR > 40;
replace DUR = 40 if DUR > 40;

/* ****************************************** */
/* EPISODE SPLITTING					      */
/* ****************************************** */

stset DUR, failure(EverInUnion) id(RecNo);

/* ****************************************** */
/* MODELS								      */
/* ****************************************** */

/* Estimation Educ LOW */

xi: stpiece if m_cohort==5 & M_EDUC==0, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==4 & M_EDUC==0, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==3 & M_EDUC==0, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==2 & M_EDUC==0, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==1 & M_EDUC==0, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );

/* Estimation Educ MED */

xi: stpiece if m_cohort==5 & M_EDUC==1, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==4 & M_EDUC==1, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==3 & M_EDUC==1, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==2 & M_EDUC==1, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==1 & M_EDUC==1, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );

/* Estimation Educ HIGH */

xi: stpiece if m_cohort==5 & M_EDUC==2, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==4 & M_EDUC==2, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==3 & M_EDUC==2, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==2 & M_EDUC==2, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );
xi: stpiece if m_cohort==1 & M_EDUC==2, tp( 2, 4, 6, 8, 10, 12, 14, 16, 18 20, 22, 24, 26, 28, 30, 32, 34, 36, 38 );


