/*
CREATION OF AN ANALYSIS FILE FOR BIRTHS 
DATA FROM MICS MAURETANIA
MARTIN SPIELAUER, 2016

Input Data:

    - bh.dta	Birth histories
    - wm.dta	Females	

Output File

    - m_mics_fertility.dta

Variables of output file:

    - M_ID		Person ID (women)
    - M_BIRTH	Birth date (women)
    - M_WEIGHT	Record Weight
    - M_Bnn		Birth dates of children nn 01-14 
    - M_EDUC	Primary education: never entered / dropout / finish level 5+
    - M_MAR		Date of first marriage

*/

/*******************************************/
/* Settings and file of birth records      */
/*******************************************/

clear
capture log close
#delimit; 
set more off;
set linesize 255;
log using "C:\Users\pc\Desktop\usb_dynamiscmap\Log files\11_MICS_CreateAnalysisFile__cmap.smcl", replace smcl;
use "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\bh.dta" ;
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_fertility.dta", replace;

/*******************************************/
/* Variables from bh.dta                   */
/*******************************************/

/* create id's for mothers and sort observations by birth order*/

gen M_ID = HH1*10000 + HH2*100 + LN;
sort M_ID BHLN;

/* dates of child births by birth order written to the first child's record */
 
gen M_B01 = .; replace M_B01 = BH4C if BHLN==1;
gen M_B02 = .; replace M_B02 = BH4C[_n+1]  if BHLN==1 & BHLN[_n+1]==2;
gen M_B03 = .; replace M_B03 = BH4C[_n+2]  if BHLN==1 & BHLN[_n+2]==3;
gen M_B04 = .; replace M_B04 = BH4C[_n+3]  if BHLN==1 & BHLN[_n+3]==4;
gen M_B05 = .; replace M_B05 = BH4C[_n+4]  if BHLN==1 & BHLN[_n+4]==5;
gen M_B06 = .; replace M_B06 = BH4C[_n+5]  if BHLN==1 & BHLN[_n+5]==6;
gen M_B07 = .; replace M_B07 = BH4C[_n+6]  if BHLN==1 & BHLN[_n+6]==7;
gen M_B08 = .; replace M_B08 = BH4C[_n+7]  if BHLN==1 & BHLN[_n+7]==8;
gen M_B09 = .; replace M_B09 = BH4C[_n+8]  if BHLN==1 & BHLN[_n+8]==9;
gen M_B10 = .; replace M_B10 = BH4C[_n+9]  if BHLN==1 & BHLN[_n+9]==10;
gen M_B11 = .; replace M_B11 = BH4C[_n+10] if BHLN==1 & BHLN[_n+10]==11;
gen M_B12 = .; replace M_B12 = BH4C[_n+11] if BHLN==1 & BHLN[_n+11]==12;
gen M_B13 = .; replace M_B13 = BH4C[_n+12] if BHLN==1 & BHLN[_n+12]==13;
gen M_B14 = .; replace M_B14 = BH4C[_n+13] if BHLN==1 & BHLN[_n+13]==14;

/* keep only records of first births (containing all infos on siblings) */
drop if BHLN>1;

/* keep only analysis variables */
keep M_*;

/* save birth file */
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_fertility.dta", replace;

/*******************************************/
/* Merge file with wm.dta                  */
/*******************************************/

clear all;
use "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\wm.dta" ;

gen M_ID = HH1*10000 + HH2*100 + LN; sort M_ID;
merge 1:1  M_ID using C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_fertility.dta; drop if _merge==2;
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_fertility.dta", replace;

/*******************************************/
/* Variables from wm.dta                   */
/*******************************************/

/* Weight */
gen M_WEIGHT = wmweight;
drop if M_WEIGHT == 0;

/* Birth date */
gen	M_BIRTH = WDOB;

/* Education */
gen	M_EDUC = 0;
replace M_EDUC = 1 if WB4 == 1 & WB5 < 5;
replace M_EDUC = 2 if WB4 == 1 & WB5 >= 5;
replace M_EDUC = 2 if WB4 > 1 & WB4 < 5;
tab M_EDUC welevel, miss;

/* Date of first marriage */
gen	M_MAR = WDOM;
gen	M_INTERV = WDOI;

/* keep analysis variables and save final file */
keep M_*;
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_fertility.dta", replace;

log close;

