/*
    FERTILITY
	MARTIN SPIELAUER, 2016
*/

/* ************************* */
/* DATA: RESIDENT POPULATION */
/* ************************* */

clear all
#delimit; 
use "D:\Dropbox\WorldBank2016_MS\Census\m_census_residents.dta";

/* ************************* */
/* VARIABLES                 */
/* ************************* */

/* Drop Males */
drop if M_MALE == 1;

/* Age 6 months ago, drop if < 10 or > 49*/
gen m_ageago = M_AGE-0.5;
	replace m_ageago = int(m_ageago); 
	drop if m_ageago < 10;
	drop if m_ageago > 49;
	char m_ageago[omit]20;

/* Birth in past 12 months */	
gen m_birth = 0; replace m_birth = 1 if M_BIR12 > 0;

/* Ever in union */		
gen m_union = 0; replace m_union = 1 if M_AGEMAR !=.;
	
/* Age segments */
gen m_age14 = m_ageago; replace m_age14=14 if m_age14 > 14;
	char m_age14[omit]14;	

gen m_age15 = m_ageago; 
	replace m_age15=15 if m_age15 < 15;
	replace m_age15=45 if m_age15>45;
	char m_age15[omit]15;	

/* Parity a year ago */
gen m_parago = M_PARITY - m_birth;

	
/* ************************* */
/* MODELS                    */
/* ************************* */

/* First Birth */

/* below 15 (education proportional)*/
xi: logit m_birth i.m_age14 i.M_EDUC [iweight=M_WEIGHT] if m_ageago < 15 & m_union == 0 & m_parago==0;
xi: logit m_birth i.m_age14 i.M_EDUC i.M_POR [iweight=M_WEIGHT] if m_ageago < 15 & m_union == 1 & m_parago==0;

/* 15+ out of union (education proportional)*/
xi: logit m_birth i.m_age15 i.M_EDUC i.M_POR [iweight=M_WEIGHT] if m_ageago >= 15 & m_union == 0 & m_parago==0;

/* 15+ in union (by education)*/
xi: logit m_birth i.m_age15 i.M_POR [iweight=M_WEIGHT] if m_ageago >= 15 & m_union == 1 & M_EDUC==0 & m_parago==0;
xi: logit m_birth i.m_age15 i.M_POR [iweight=M_WEIGHT] if m_ageago >= 15 & m_union == 1 & M_EDUC==1 & m_parago==0;
xi: logit m_birth i.m_age15 i.M_POR [iweight=M_WEIGHT] if m_ageago >= 15 & m_union == 1 & M_EDUC==2 & m_parago==0;

/* Higher order births */

xi: logit m_birth i.m_parago i.M_POR i.M_EDUC i.m_union [iweight=M_WEIGHT] if m_parago>0; 
