/*
CREATION OF AN ANALYSIS FILE FOR CHILD MORTALITY 
DATA FROM MICS MAURETANIA
MARTIN SPIELAUER, 2016

Input Data:

    - bh.dta	Birth histories
    - wm.dta	Females	

Output File

    - m_mics_childmortality.dta

Variables of output file:

	- M_BIRTH	Date of birth
	- M_DEATH	Date of death
	- M_MALE	Male
	- M_ID		ID Mother
    - M_AGEMO	Mothers age at birth
    - M_WEIGHT	Record Weight
    - M_EDUCMO	Primary education of mother: never entered / dropout / finish level 5+
*/

/*******************************************/
/* Settings and file of birth records      */
/*******************************************/

clear
#delimit; 
capture log close
#delimit; 
set more off;
set linesize 255;
log using "C:\Users\pc\Desktop\usb_dynamiscmap\Log files\15_MICS_CreateAnalysisChildMortality_cmap.smcl", replace smcl;
use "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\bh.dta" ;
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_childmortality.dta", replace;

/*******************************************/
/* Variables from bh.dta                   */
/*******************************************/

/* create id's for mothers */

gen M_ID = HH1*10000 + HH2*100 + LN;

/* date of child birth, death, and sex*/

gen	M_BIRTH = BH4C;
gen	M_DEATH = .; replace M_DEATH = M_BIRTH + BH9C if BH9C != .;
gen	M_MALE = 0; replace M_MALE = 1 if BH3 == 1;

/* keep only analysis variables */
keep M_*;

/* save birth file */
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_childmortality.dta", replace;

/*******************************************/
/* Merge file with wm.dta                  */
/*******************************************/

clear all;
use "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\wm.dta" ;

gen M_ID = HH1*10000 + HH2*100 + LN; sort M_ID;
merge 1:n  M_ID using C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_childmortality.dta; drop if _merge==2;
drop if M_BIRTH == .; 
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\_mics_childmortality.dta", replace;

/*******************************************/
/* Variables from wm.dta                   */
/*******************************************/

/* Weight */
gen M_WEIGHT = wmweight;
drop if M_WEIGHT == 0;

/* Birth date */
gen	M_AGEMO =  M_BIRTH - WDOB;

/* Education */
gen	M_EDUCMO = 0;
replace M_EDUCMO = 1 if WB4 == 1 & WB5 < 5;
replace M_EDUCMO = 2 if WB4 == 1 & WB5 >= 5;
replace M_EDUCMO = 2 if WB4 > 1 & WB4 < 5;

/* Interview time*/

gen M_INTERV = WDOI;

/* keep analysis variables and save final file */
keep M_*;
save "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_childmortality.dta", replace;

log close;

